# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
from io import IOBase
from typing import Any, Callable, Dict, IO, Optional, TypeVar, Union, cast, overload

from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    ResourceNotModifiedError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.pipeline.transport import AsyncHttpResponse
from azure.core.polling import AsyncLROPoller, AsyncNoPolling, AsyncPollingMethod
from azure.core.rest import HttpRequest
from azure.core.tracing.decorator_async import distributed_trace_async
from azure.core.utils import case_insensitive_dict
from azure.mgmt.core.exceptions import ARMErrorFormat
from azure.mgmt.core.polling.async_arm_polling import AsyncARMPolling

from ... import models as _models
from ..._vendor import _convert_request
from ...operations._subscriptions_operations import (
    build_compile_query_request,
    build_list_quotas_request,
    build_sample_input_request,
    build_test_input_request,
    build_test_output_request,
    build_test_query_request,
)

T = TypeVar("T")
ClsType = Optional[Callable[[PipelineResponse[HttpRequest, AsyncHttpResponse], T, Dict[str, Any]], Any]]


class SubscriptionsOperations:
    """
    .. warning::
        **DO NOT** instantiate this class directly.

        Instead, you should access the following operations through
        :class:`~azure.mgmt.streamanalytics.aio.StreamAnalyticsManagementClient`'s
        :attr:`subscriptions` attribute.
    """

    models = _models

    def __init__(self, *args, **kwargs) -> None:
        input_args = list(args)
        self._client = input_args.pop(0) if input_args else kwargs.pop("client")
        self._config = input_args.pop(0) if input_args else kwargs.pop("config")
        self._serialize = input_args.pop(0) if input_args else kwargs.pop("serializer")
        self._deserialize = input_args.pop(0) if input_args else kwargs.pop("deserializer")

    @distributed_trace_async
    async def list_quotas(self, location: str, **kwargs: Any) -> _models.SubscriptionQuotasListResult:
        """Retrieves the subscription's current quota information in a particular region.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: SubscriptionQuotasListResult or the result of cls(response)
        :rtype: ~azure.mgmt.streamanalytics.models.SubscriptionQuotasListResult
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        cls: ClsType[_models.SubscriptionQuotasListResult] = kwargs.pop("cls", None)

        request = build_list_quotas_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            template_url=self.list_quotas.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.Error, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("SubscriptionQuotasListResult", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    list_quotas.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/quotas"
    }

    async def _test_query_initial(
        self, location: str, test_query: Union[_models.TestQuery, IO], **kwargs: Any
    ) -> Optional[_models.QueryTestingResult]:
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[Optional[_models.QueryTestingResult]] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(test_query, (IOBase, bytes)):
            _content = test_query
        else:
            _json = self._serialize.body(test_query, "TestQuery")

        request = build_test_query_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self._test_query_initial.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200, 202]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.Error, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = None
        if response.status_code == 200:
            deserialized = self._deserialize("QueryTestingResult", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    _test_query_initial.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/testQuery"
    }

    @overload
    async def begin_test_query(
        self, location: str, test_query: _models.TestQuery, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.QueryTestingResult]:
        """Test the Stream Analytics query on a sample input.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_query: The query testing object that defines the input, output, and transformation
         for the query testing. Required.
        :type test_query: ~azure.mgmt.streamanalytics.models.TestQuery
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either QueryTestingResult or the result of
         cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.QueryTestingResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    async def begin_test_query(
        self, location: str, test_query: IO, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.QueryTestingResult]:
        """Test the Stream Analytics query on a sample input.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_query: The query testing object that defines the input, output, and transformation
         for the query testing. Required.
        :type test_query: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either QueryTestingResult or the result of
         cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.QueryTestingResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace_async
    async def begin_test_query(
        self, location: str, test_query: Union[_models.TestQuery, IO], **kwargs: Any
    ) -> AsyncLROPoller[_models.QueryTestingResult]:
        """Test the Stream Analytics query on a sample input.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_query: The query testing object that defines the input, output, and transformation
         for the query testing. Is either a TestQuery type or a IO type. Required.
        :type test_query: ~azure.mgmt.streamanalytics.models.TestQuery or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either QueryTestingResult or the result of
         cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.QueryTestingResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.QueryTestingResult] = kwargs.pop("cls", None)
        polling: Union[bool, AsyncPollingMethod] = kwargs.pop("polling", True)
        lro_delay = kwargs.pop("polling_interval", self._config.polling_interval)
        cont_token: Optional[str] = kwargs.pop("continuation_token", None)
        if cont_token is None:
            raw_result = await self._test_query_initial(
                location=location,
                test_query=test_query,
                api_version=api_version,
                content_type=content_type,
                cls=lambda x, y, z: x,
                headers=_headers,
                params=_params,
                **kwargs
            )
        kwargs.pop("error_map", None)

        def get_long_running_output(pipeline_response):
            deserialized = self._deserialize("QueryTestingResult", pipeline_response)
            if cls:
                return cls(pipeline_response, deserialized, {})
            return deserialized

        if polling is True:
            polling_method: AsyncPollingMethod = cast(
                AsyncPollingMethod, AsyncARMPolling(lro_delay, lro_options={"final-state-via": "location"}, **kwargs)
            )
        elif polling is False:
            polling_method = cast(AsyncPollingMethod, AsyncNoPolling())
        else:
            polling_method = polling
        if cont_token:
            return AsyncLROPoller.from_continuation_token(
                polling_method=polling_method,
                continuation_token=cont_token,
                client=self._client,
                deserialization_callback=get_long_running_output,
            )
        return AsyncLROPoller(self._client, raw_result, get_long_running_output, polling_method)  # type: ignore

    begin_test_query.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/testQuery"
    }

    @overload
    async def compile_query(
        self,
        location: str,
        compile_query: _models.CompileQuery,
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> _models.QueryCompilationResult:
        """Compile the Stream Analytics query.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param compile_query: The query compilation object which defines the input, output, and
         transformation for the query compilation. Required.
        :type compile_query: ~azure.mgmt.streamanalytics.models.CompileQuery
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: QueryCompilationResult or the result of cls(response)
        :rtype: ~azure.mgmt.streamanalytics.models.QueryCompilationResult
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    async def compile_query(
        self, location: str, compile_query: IO, *, content_type: str = "application/json", **kwargs: Any
    ) -> _models.QueryCompilationResult:
        """Compile the Stream Analytics query.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param compile_query: The query compilation object which defines the input, output, and
         transformation for the query compilation. Required.
        :type compile_query: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: QueryCompilationResult or the result of cls(response)
        :rtype: ~azure.mgmt.streamanalytics.models.QueryCompilationResult
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace_async
    async def compile_query(
        self, location: str, compile_query: Union[_models.CompileQuery, IO], **kwargs: Any
    ) -> _models.QueryCompilationResult:
        """Compile the Stream Analytics query.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param compile_query: The query compilation object which defines the input, output, and
         transformation for the query compilation. Is either a CompileQuery type or a IO type. Required.
        :type compile_query: ~azure.mgmt.streamanalytics.models.CompileQuery or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: QueryCompilationResult or the result of cls(response)
        :rtype: ~azure.mgmt.streamanalytics.models.QueryCompilationResult
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.QueryCompilationResult] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(compile_query, (IOBase, bytes)):
            _content = compile_query
        else:
            _json = self._serialize.body(compile_query, "CompileQuery")

        request = build_compile_query_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self.compile_query.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.Error, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("QueryCompilationResult", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    compile_query.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/compileQuery"
    }

    async def _sample_input_initial(
        self, location: str, sample_input: Union[_models.SampleInput, IO], **kwargs: Any
    ) -> _models.SampleInputResult:
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.SampleInputResult] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(sample_input, (IOBase, bytes)):
            _content = sample_input
        else:
            _json = self._serialize.body(sample_input, "SampleInput")

        request = build_sample_input_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self._sample_input_initial.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [202]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.Error, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("SampleInputResult", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    _sample_input_initial.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/sampleInput"
    }

    @overload
    async def begin_sample_input(
        self, location: str, sample_input: _models.SampleInput, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.SampleInputResult]:
        """Sample the Stream Analytics input data.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param sample_input: Defines the necessary parameters for sampling the Stream Analytics input
         data. Required.
        :type sample_input: ~azure.mgmt.streamanalytics.models.SampleInput
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either SampleInputResult or the result of
         cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.SampleInputResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    async def begin_sample_input(
        self, location: str, sample_input: IO, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.SampleInputResult]:
        """Sample the Stream Analytics input data.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param sample_input: Defines the necessary parameters for sampling the Stream Analytics input
         data. Required.
        :type sample_input: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either SampleInputResult or the result of
         cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.SampleInputResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace_async
    async def begin_sample_input(
        self, location: str, sample_input: Union[_models.SampleInput, IO], **kwargs: Any
    ) -> AsyncLROPoller[_models.SampleInputResult]:
        """Sample the Stream Analytics input data.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param sample_input: Defines the necessary parameters for sampling the Stream Analytics input
         data. Is either a SampleInput type or a IO type. Required.
        :type sample_input: ~azure.mgmt.streamanalytics.models.SampleInput or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either SampleInputResult or the result of
         cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.SampleInputResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.SampleInputResult] = kwargs.pop("cls", None)
        polling: Union[bool, AsyncPollingMethod] = kwargs.pop("polling", True)
        lro_delay = kwargs.pop("polling_interval", self._config.polling_interval)
        cont_token: Optional[str] = kwargs.pop("continuation_token", None)
        if cont_token is None:
            raw_result = await self._sample_input_initial(
                location=location,
                sample_input=sample_input,
                api_version=api_version,
                content_type=content_type,
                cls=lambda x, y, z: x,
                headers=_headers,
                params=_params,
                **kwargs
            )
        kwargs.pop("error_map", None)

        def get_long_running_output(pipeline_response):
            deserialized = self._deserialize("SampleInputResult", pipeline_response)
            if cls:
                return cls(pipeline_response, deserialized, {})
            return deserialized

        if polling is True:
            polling_method: AsyncPollingMethod = cast(
                AsyncPollingMethod, AsyncARMPolling(lro_delay, lro_options={"final-state-via": "location"}, **kwargs)
            )
        elif polling is False:
            polling_method = cast(AsyncPollingMethod, AsyncNoPolling())
        else:
            polling_method = polling
        if cont_token:
            return AsyncLROPoller.from_continuation_token(
                polling_method=polling_method,
                continuation_token=cont_token,
                client=self._client,
                deserialization_callback=get_long_running_output,
            )
        return AsyncLROPoller(self._client, raw_result, get_long_running_output, polling_method)  # type: ignore

    begin_sample_input.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/sampleInput"
    }

    async def _test_input_initial(
        self, location: str, test_input: Union[_models.TestInput, IO], **kwargs: Any
    ) -> _models.TestDatasourceResult:
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.TestDatasourceResult] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(test_input, (IOBase, bytes)):
            _content = test_input
        else:
            _json = self._serialize.body(test_input, "TestInput")

        request = build_test_input_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self._test_input_initial.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [202]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.Error, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("TestDatasourceResult", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    _test_input_initial.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/testInput"
    }

    @overload
    async def begin_test_input(
        self, location: str, test_input: _models.TestInput, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.TestDatasourceResult]:
        """Test the Stream Analytics input.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_input: Defines the necessary parameters for testing the Stream Analytics input.
         Required.
        :type test_input: ~azure.mgmt.streamanalytics.models.TestInput
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either TestDatasourceResult or the result
         of cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.TestDatasourceResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    async def begin_test_input(
        self, location: str, test_input: IO, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.TestDatasourceResult]:
        """Test the Stream Analytics input.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_input: Defines the necessary parameters for testing the Stream Analytics input.
         Required.
        :type test_input: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either TestDatasourceResult or the result
         of cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.TestDatasourceResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace_async
    async def begin_test_input(
        self, location: str, test_input: Union[_models.TestInput, IO], **kwargs: Any
    ) -> AsyncLROPoller[_models.TestDatasourceResult]:
        """Test the Stream Analytics input.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_input: Defines the necessary parameters for testing the Stream Analytics input. Is
         either a TestInput type or a IO type. Required.
        :type test_input: ~azure.mgmt.streamanalytics.models.TestInput or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either TestDatasourceResult or the result
         of cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.TestDatasourceResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.TestDatasourceResult] = kwargs.pop("cls", None)
        polling: Union[bool, AsyncPollingMethod] = kwargs.pop("polling", True)
        lro_delay = kwargs.pop("polling_interval", self._config.polling_interval)
        cont_token: Optional[str] = kwargs.pop("continuation_token", None)
        if cont_token is None:
            raw_result = await self._test_input_initial(
                location=location,
                test_input=test_input,
                api_version=api_version,
                content_type=content_type,
                cls=lambda x, y, z: x,
                headers=_headers,
                params=_params,
                **kwargs
            )
        kwargs.pop("error_map", None)

        def get_long_running_output(pipeline_response):
            deserialized = self._deserialize("TestDatasourceResult", pipeline_response)
            if cls:
                return cls(pipeline_response, deserialized, {})
            return deserialized

        if polling is True:
            polling_method: AsyncPollingMethod = cast(
                AsyncPollingMethod, AsyncARMPolling(lro_delay, lro_options={"final-state-via": "location"}, **kwargs)
            )
        elif polling is False:
            polling_method = cast(AsyncPollingMethod, AsyncNoPolling())
        else:
            polling_method = polling
        if cont_token:
            return AsyncLROPoller.from_continuation_token(
                polling_method=polling_method,
                continuation_token=cont_token,
                client=self._client,
                deserialization_callback=get_long_running_output,
            )
        return AsyncLROPoller(self._client, raw_result, get_long_running_output, polling_method)  # type: ignore

    begin_test_input.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/testInput"
    }

    async def _test_output_initial(
        self, location: str, test_output: Union[_models.TestOutput, IO], **kwargs: Any
    ) -> _models.TestDatasourceResult:
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.TestDatasourceResult] = kwargs.pop("cls", None)

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(test_output, (IOBase, bytes)):
            _content = test_output
        else:
            _json = self._serialize.body(test_output, "TestOutput")

        request = build_test_output_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self._test_output_initial.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # pylint: disable=protected-access
            request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [202]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.Error, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("TestDatasourceResult", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    _test_output_initial.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/testOutput"
    }

    @overload
    async def begin_test_output(
        self, location: str, test_output: _models.TestOutput, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.TestDatasourceResult]:
        """Test the Stream Analytics output.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_output: Defines the necessary parameters for testing the Stream Analytics output.
         Required.
        :type test_output: ~azure.mgmt.streamanalytics.models.TestOutput
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either TestDatasourceResult or the result
         of cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.TestDatasourceResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    async def begin_test_output(
        self, location: str, test_output: IO, *, content_type: str = "application/json", **kwargs: Any
    ) -> AsyncLROPoller[_models.TestDatasourceResult]:
        """Test the Stream Analytics output.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_output: Defines the necessary parameters for testing the Stream Analytics output.
         Required.
        :type test_output: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either TestDatasourceResult or the result
         of cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.TestDatasourceResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace_async
    async def begin_test_output(
        self, location: str, test_output: Union[_models.TestOutput, IO], **kwargs: Any
    ) -> AsyncLROPoller[_models.TestDatasourceResult]:
        """Test the Stream Analytics output.

        :param location: The region to which the request is sent. You can find out which regions Azure
         Stream Analytics is supported in here: https://azure.microsoft.com/en-us/regions/. Required.
        :type location: str
        :param test_output: Defines the necessary parameters for testing the Stream Analytics output.
         Is either a TestOutput type or a IO type. Required.
        :type test_output: ~azure.mgmt.streamanalytics.models.TestOutput or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :keyword str continuation_token: A continuation token to restart a poller from a saved state.
        :keyword polling: By default, your polling method will be AsyncARMPolling. Pass in False for
         this operation to not poll, or pass in your own initialized polling object for a personal
         polling strategy.
        :paramtype polling: bool or ~azure.core.polling.AsyncPollingMethod
        :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
         Retry-After header is present.
        :return: An instance of AsyncLROPoller that returns either TestDatasourceResult or the result
         of cls(response)
        :rtype:
         ~azure.core.polling.AsyncLROPoller[~azure.mgmt.streamanalytics.models.TestDatasourceResult]
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", "2021-10-01-preview"))
        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        cls: ClsType[_models.TestDatasourceResult] = kwargs.pop("cls", None)
        polling: Union[bool, AsyncPollingMethod] = kwargs.pop("polling", True)
        lro_delay = kwargs.pop("polling_interval", self._config.polling_interval)
        cont_token: Optional[str] = kwargs.pop("continuation_token", None)
        if cont_token is None:
            raw_result = await self._test_output_initial(
                location=location,
                test_output=test_output,
                api_version=api_version,
                content_type=content_type,
                cls=lambda x, y, z: x,
                headers=_headers,
                params=_params,
                **kwargs
            )
        kwargs.pop("error_map", None)

        def get_long_running_output(pipeline_response):
            deserialized = self._deserialize("TestDatasourceResult", pipeline_response)
            if cls:
                return cls(pipeline_response, deserialized, {})
            return deserialized

        if polling is True:
            polling_method: AsyncPollingMethod = cast(
                AsyncPollingMethod, AsyncARMPolling(lro_delay, lro_options={"final-state-via": "location"}, **kwargs)
            )
        elif polling is False:
            polling_method = cast(AsyncPollingMethod, AsyncNoPolling())
        else:
            polling_method = polling
        if cont_token:
            return AsyncLROPoller.from_continuation_token(
                polling_method=polling_method,
                continuation_token=cont_token,
                client=self._client,
                deserialization_callback=get_long_running_output,
            )
        return AsyncLROPoller(self._client, raw_result, get_long_running_output, polling_method)  # type: ignore

    begin_test_output.metadata = {
        "url": "/subscriptions/{subscriptionId}/providers/Microsoft.StreamAnalytics/locations/{location}/testOutput"
    }



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._models_py3 import AggregateFunctionProperties
from ._models_py3 import AvroSerialization
from ._models_py3 import AzureDataExplorerOutputDataSource
from ._models_py3 import AzureDataLakeStoreOutputDataSource
from ._models_py3 import AzureDataLakeStoreOutputDataSourceProperties
from ._models_py3 import AzureFunctionOutputDataSource
from ._models_py3 import AzureMachineLearningServiceFunctionBinding
from ._models_py3 import AzureMachineLearningServiceFunctionRetrieveDefaultDefinitionParameters
from ._models_py3 import AzureMachineLearningServiceInputColumn
from ._models_py3 import AzureMachineLearningServiceInputs
from ._models_py3 import AzureMachineLearningServiceOutputColumn
from ._models_py3 import AzureMachineLearningStudioFunctionBinding
from ._models_py3 import AzureMachineLearningStudioFunctionRetrieveDefaultDefinitionParameters
from ._models_py3 import AzureMachineLearningStudioInputColumn
from ._models_py3 import AzureMachineLearningStudioInputs
from ._models_py3 import AzureMachineLearningStudioOutputColumn
from ._models_py3 import AzureSqlDatabaseDataSourceProperties
from ._models_py3 import AzureSqlDatabaseOutputDataSource
from ._models_py3 import AzureSqlDatabaseOutputDataSourceProperties
from ._models_py3 import AzureSqlReferenceInputDataSource
from ._models_py3 import AzureSynapseDataSourceProperties
from ._models_py3 import AzureSynapseOutputDataSource
from ._models_py3 import AzureSynapseOutputDataSourceProperties
from ._models_py3 import AzureTableOutputDataSource
from ._models_py3 import BlobDataSourceProperties
from ._models_py3 import BlobOutputDataSource
from ._models_py3 import BlobOutputDataSourceProperties
from ._models_py3 import BlobReferenceInputDataSource
from ._models_py3 import BlobReferenceInputDataSourceProperties
from ._models_py3 import BlobStreamInputDataSource
from ._models_py3 import BlobStreamInputDataSourceProperties
from ._models_py3 import CSharpFunctionBinding
from ._models_py3 import CSharpFunctionRetrieveDefaultDefinitionParameters
from ._models_py3 import Cluster
from ._models_py3 import ClusterInfo
from ._models_py3 import ClusterJob
from ._models_py3 import ClusterJobListResult
from ._models_py3 import ClusterListResult
from ._models_py3 import ClusterProperties
from ._models_py3 import ClusterSku
from ._models_py3 import CompileQuery
from ._models_py3 import Compression
from ._models_py3 import CsvSerialization
from ._models_py3 import CustomClrSerialization
from ._models_py3 import DeltaSerialization
from ._models_py3 import DiagnosticCondition
from ._models_py3 import Diagnostics
from ._models_py3 import DocumentDbOutputDataSource
from ._models_py3 import Error
from ._models_py3 import ErrorDetails
from ._models_py3 import ErrorError
from ._models_py3 import ErrorResponse
from ._models_py3 import EventGridStreamInputDataSource
from ._models_py3 import EventHubDataSourceProperties
from ._models_py3 import EventHubOutputDataSource
from ._models_py3 import EventHubOutputDataSourceProperties
from ._models_py3 import EventHubStreamInputDataSource
from ._models_py3 import EventHubStreamInputDataSourceProperties
from ._models_py3 import EventHubV2OutputDataSource
from ._models_py3 import EventHubV2StreamInputDataSource
from ._models_py3 import External
from ._models_py3 import FileReferenceInputDataSource
from ._models_py3 import Function
from ._models_py3 import FunctionBinding
from ._models_py3 import FunctionInput
from ._models_py3 import FunctionListResult
from ._models_py3 import FunctionOutput
from ._models_py3 import FunctionProperties
from ._models_py3 import FunctionRetrieveDefaultDefinitionParameters
from ._models_py3 import GatewayMessageBusOutputDataSource
from ._models_py3 import GatewayMessageBusOutputDataSourceProperties
from ._models_py3 import GatewayMessageBusSourceProperties
from ._models_py3 import GatewayMessageBusStreamInputDataSource
from ._models_py3 import GatewayMessageBusStreamInputDataSourceProperties
from ._models_py3 import GetStreamingJobSkuResult
from ._models_py3 import GetStreamingJobSkuResultSku
from ._models_py3 import GetStreamingJobSkuResults
from ._models_py3 import Identity
from ._models_py3 import Input
from ._models_py3 import InputListResult
from ._models_py3 import InputProperties
from ._models_py3 import InputWatermarkProperties
from ._models_py3 import IoTHubStreamInputDataSource
from ._models_py3 import JavaScriptFunctionBinding
from ._models_py3 import JavaScriptFunctionRetrieveDefaultDefinitionParameters
from ._models_py3 import JobStorageAccount
from ._models_py3 import JsonSerialization
from ._models_py3 import LastOutputEventTimestamp
from ._models_py3 import OAuthBasedDataSourceProperties
from ._models_py3 import Operation
from ._models_py3 import OperationDisplay
from ._models_py3 import OperationListResult
from ._models_py3 import Output
from ._models_py3 import OutputDataSource
from ._models_py3 import OutputListResult
from ._models_py3 import OutputWatermarkProperties
from ._models_py3 import ParquetSerialization
from ._models_py3 import PostgreSQLDataSourceProperties
from ._models_py3 import PostgreSQLOutputDataSource
from ._models_py3 import PostgreSQLOutputDataSourceProperties
from ._models_py3 import PowerBIOutputDataSource
from ._models_py3 import PowerBIOutputDataSourceProperties
from ._models_py3 import PrivateEndpoint
from ._models_py3 import PrivateEndpointListResult
from ._models_py3 import PrivateEndpointProperties
from ._models_py3 import PrivateLinkConnectionState
from ._models_py3 import PrivateLinkServiceConnection
from ._models_py3 import ProxyResource
from ._models_py3 import QueryCompilationError
from ._models_py3 import QueryCompilationResult
from ._models_py3 import QueryFunction
from ._models_py3 import QueryInput
from ._models_py3 import QueryTestingResult
from ._models_py3 import RawOutputDatasource
from ._models_py3 import RawReferenceInputDataSource
from ._models_py3 import RawStreamInputDataSource
from ._models_py3 import ReferenceInputDataSource
from ._models_py3 import ReferenceInputProperties
from ._models_py3 import RefreshConfiguration
from ._models_py3 import Resource
from ._models_py3 import ResourceTestStatus
from ._models_py3 import SampleInput
from ._models_py3 import SampleInputResult
from ._models_py3 import ScalarFunctionProperties
from ._models_py3 import ScaleStreamingJobParameters
from ._models_py3 import Serialization
from ._models_py3 import ServiceBusDataSourceProperties
from ._models_py3 import ServiceBusQueueOutputDataSource
from ._models_py3 import ServiceBusQueueOutputDataSourceProperties
from ._models_py3 import ServiceBusTopicOutputDataSource
from ._models_py3 import ServiceBusTopicOutputDataSourceProperties
from ._models_py3 import Sku
from ._models_py3 import SkuCapacity
from ._models_py3 import StartStreamingJobParameters
from ._models_py3 import StorageAccount
from ._models_py3 import StreamInputDataSource
from ._models_py3 import StreamInputProperties
from ._models_py3 import StreamingJob
from ._models_py3 import StreamingJobListResult
from ._models_py3 import SubResource
from ._models_py3 import SubscriptionQuota
from ._models_py3 import SubscriptionQuotasListResult
from ._models_py3 import TestDatasourceResult
from ._models_py3 import TestInput
from ._models_py3 import TestOutput
from ._models_py3 import TestQuery
from ._models_py3 import TestQueryDiagnostics
from ._models_py3 import TrackedResource
from ._models_py3 import Transformation

from ._stream_analytics_management_client_enums import AuthenticationMode
from ._stream_analytics_management_client_enums import BlobWriteMode
from ._stream_analytics_management_client_enums import ClusterProvisioningState
from ._stream_analytics_management_client_enums import ClusterSkuName
from ._stream_analytics_management_client_enums import CompatibilityLevel
from ._stream_analytics_management_client_enums import CompressionType
from ._stream_analytics_management_client_enums import ContentStoragePolicy
from ._stream_analytics_management_client_enums import Encoding
from ._stream_analytics_management_client_enums import EventGridEventSchemaType
from ._stream_analytics_management_client_enums import EventSerializationType
from ._stream_analytics_management_client_enums import EventsOutOfOrderPolicy
from ._stream_analytics_management_client_enums import InputWatermarkMode
from ._stream_analytics_management_client_enums import JobState
from ._stream_analytics_management_client_enums import JobType
from ._stream_analytics_management_client_enums import JsonOutputSerializationFormat
from ._stream_analytics_management_client_enums import OutputErrorPolicy
from ._stream_analytics_management_client_enums import OutputStartMode
from ._stream_analytics_management_client_enums import OutputWatermarkMode
from ._stream_analytics_management_client_enums import QueryTestingResultStatus
from ._stream_analytics_management_client_enums import RefreshType
from ._stream_analytics_management_client_enums import ResourceType
from ._stream_analytics_management_client_enums import SampleInputResultStatus
from ._stream_analytics_management_client_enums import SkuCapacityScaleType
from ._stream_analytics_management_client_enums import SkuName
from ._stream_analytics_management_client_enums import TestDatasourceResultStatus
from ._stream_analytics_management_client_enums import UpdatableUdfRefreshType
from ._stream_analytics_management_client_enums import UpdateMode
from ._patch import __all__ as _patch_all
from ._patch import *  # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AggregateFunctionProperties",
    "AvroSerialization",
    "AzureDataExplorerOutputDataSource",
    "AzureDataLakeStoreOutputDataSource",
    "AzureDataLakeStoreOutputDataSourceProperties",
    "AzureFunctionOutputDataSource",
    "AzureMachineLearningServiceFunctionBinding",
    "AzureMachineLearningServiceFunctionRetrieveDefaultDefinitionParameters",
    "AzureMachineLearningServiceInputColumn",
    "AzureMachineLearningServiceInputs",
    "AzureMachineLearningServiceOutputColumn",
    "AzureMachineLearningStudioFunctionBinding",
    "AzureMachineLearningStudioFunctionRetrieveDefaultDefinitionParameters",
    "AzureMachineLearningStudioInputColumn",
    "AzureMachineLearningStudioInputs",
    "AzureMachineLearningStudioOutputColumn",
    "AzureSqlDatabaseDataSourceProperties",
    "AzureSqlDatabaseOutputDataSource",
    "AzureSqlDatabaseOutputDataSourceProperties",
    "AzureSqlReferenceInputDataSource",
    "AzureSynapseDataSourceProperties",
    "AzureSynapseOutputDataSource",
    "AzureSynapseOutputDataSourceProperties",
    "AzureTableOutputDataSource",
    "BlobDataSourceProperties",
    "BlobOutputDataSource",
    "BlobOutputDataSourceProperties",
    "BlobReferenceInputDataSource",
    "BlobReferenceInputDataSourceProperties",
    "BlobStreamInputDataSource",
    "BlobStreamInputDataSourceProperties",
    "CSharpFunctionBinding",
    "CSharpFunctionRetrieveDefaultDefinitionParameters",
    "Cluster",
    "ClusterInfo",
    "ClusterJob",
    "ClusterJobListResult",
    "ClusterListResult",
    "ClusterProperties",
    "ClusterSku",
    "CompileQuery",
    "Compression",
    "CsvSerialization",
    "CustomClrSerialization",
    "DeltaSerialization",
    "DiagnosticCondition",
    "Diagnostics",
    "DocumentDbOutputDataSource",
    "Error",
    "ErrorDetails",
    "ErrorError",
    "ErrorResponse",
    "EventGridStreamInputDataSource",
    "EventHubDataSourceProperties",
    "EventHubOutputDataSource",
    "EventHubOutputDataSourceProperties",
    "EventHubStreamInputDataSource",
    "EventHubStreamInputDataSourceProperties",
    "EventHubV2OutputDataSource",
    "EventHubV2StreamInputDataSource",
    "External",
    "FileReferenceInputDataSource",
    "Function",
    "FunctionBinding",
    "FunctionInput",
    "FunctionListResult",
    "FunctionOutput",
    "FunctionProperties",
    "FunctionRetrieveDefaultDefinitionParameters",
    "GatewayMessageBusOutputDataSource",
    "GatewayMessageBusOutputDataSourceProperties",
    "GatewayMessageBusSourceProperties",
    "GatewayMessageBusStreamInputDataSource",
    "GatewayMessageBusStreamInputDataSourceProperties",
    "GetStreamingJobSkuResult",
    "GetStreamingJobSkuResultSku",
    "GetStreamingJobSkuResults",
    "Identity",
    "Input",
    "InputListResult",
    "InputProperties",
    "InputWatermarkProperties",
    "IoTHubStreamInputDataSource",
    "JavaScriptFunctionBinding",
    "JavaScriptFunctionRetrieveDefaultDefinitionParameters",
    "JobStorageAccount",
    "JsonSerialization",
    "LastOutputEventTimestamp",
    "OAuthBasedDataSourceProperties",
    "Operation",
    "OperationDisplay",
    "OperationListResult",
    "Output",
    "OutputDataSource",
    "OutputListResult",
    "OutputWatermarkProperties",
    "ParquetSerialization",
    "PostgreSQLDataSourceProperties",
    "PostgreSQLOutputDataSource",
    "PostgreSQLOutputDataSourceProperties",
    "PowerBIOutputDataSource",
    "PowerBIOutputDataSourceProperties",
    "PrivateEndpoint",
    "PrivateEndpointListResult",
    "PrivateEndpointProperties",
    "PrivateLinkConnectionState",
    "PrivateLinkServiceConnection",
    "ProxyResource",
    "QueryCompilationError",
    "QueryCompilationResult",
    "QueryFunction",
    "QueryInput",
    "QueryTestingResult",
    "RawOutputDatasource",
    "RawReferenceInputDataSource",
    "RawStreamInputDataSource",
    "ReferenceInputDataSource",
    "ReferenceInputProperties",
    "RefreshConfiguration",
    "Resource",
    "ResourceTestStatus",
    "SampleInput",
    "SampleInputResult",
    "ScalarFunctionProperties",
    "ScaleStreamingJobParameters",
    "Serialization",
    "ServiceBusDataSourceProperties",
    "ServiceBusQueueOutputDataSource",
    "ServiceBusQueueOutputDataSourceProperties",
    "ServiceBusTopicOutputDataSource",
    "ServiceBusTopicOutputDataSourceProperties",
    "Sku",
    "SkuCapacity",
    "StartStreamingJobParameters",
    "StorageAccount",
    "StreamInputDataSource",
    "StreamInputProperties",
    "StreamingJob",
    "StreamingJobListResult",
    "SubResource",
    "SubscriptionQuota",
    "SubscriptionQuotasListResult",
    "TestDatasourceResult",
    "TestInput",
    "TestOutput",
    "TestQuery",
    "TestQueryDiagnostics",
    "TrackedResource",
    "Transformation",
    "AuthenticationMode",
    "BlobWriteMode",
    "ClusterProvisioningState",
    "ClusterSkuName",
    "CompatibilityLevel",
    "CompressionType",
    "ContentStoragePolicy",
    "Encoding",
    "EventGridEventSchemaType",
    "EventSerializationType",
    "EventsOutOfOrderPolicy",
    "InputWatermarkMode",
    "JobState",
    "JobType",
    "JsonOutputSerializationFormat",
    "OutputErrorPolicy",
    "OutputStartMode",
    "OutputWatermarkMode",
    "QueryTestingResultStatus",
    "RefreshType",
    "ResourceType",
    "SampleInputResultStatus",
    "SkuCapacityScaleType",
    "SkuName",
    "TestDatasourceResultStatus",
    "UpdatableUdfRefreshType",
    "UpdateMode",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()
